@@ -82,7 +82,7 @@ extern int oem_supermicro_get_firmware_str(char *pstr, int sz); /*oem_supermicro
  * Global variables 
  */
 static char * progname  = "ihealth";
-static char * progver   = "3.00";
+static char * progver   = "3.01";
 static char   fdebug    = 0;
 static char   fipmilan  = 0;
 static char   fcanonical = 0;
@@ -634,6 +634,11 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
 	     if (prod >= 0x200) prodstr = "(iRMC S2)"; 
 	     else prodstr = "";
              break;
+         case VENDOR_LENOVO: 
+         case VENDOR_LENOVO2: 
+	     	if (prod == 0x143) prodstr = "(x3650 M4)"; 
+	     	else prodstr = "";
+         	break;
          case VENDOR_CISCO:      /*=0x00168b, 5771.*/
 	     if (prod == 0x0005) prodstr = "(UCS C200)"; 
 	     else prodstr = "";
@@ -763,6 +768,8 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
 		 case 1636:     prodstr = "(X9DRH)"; break; /*0x0664*/
 		 case 1643:     prodstr = "(X9SRL)"; break; /*0x066b*/
 		 case 1797:	prodstr = "(X9DR7)";  break; /*0x0705*/
+		 case 2097:	prodstr = "(X10DRL)";  /*0x0831*/
+                    do_powerstate = 0;   break; 
 		 case 2137:	prodstr = "(X10DRH)"; break; /*0x0859*/
 		 case 4520:	prodstr = "(H8DGU)";  break;
 		 case 43025:	prodstr = "(H8DGU-F)"; break;
@@ -790,7 +797,7 @@ void show_devid_all(int dtype, uchar *devrec, int sdevrec)
              prodstr = "";
              break;
 	} /*end switch(prod)*/
-	if (prodstr == "") prodstr = getdmiprod();
+	if (prodstr[0] == '\0') prodstr = getdmiprod();
 	if (kcs_loops != 0) set_max_kcs_loops(kcs_loops); 
       } /*end-else BMC*/
 
