@@ -312,6 +312,8 @@ struct oemvalstr {
 #define VENDOR_XYRATEX   1993
 #define VENDOR_NEWISYS   9237
 #define VENDOR_CISCO     5771      /*=0x168B*/
+#define VENDOR_LENOVO    0x004A66
+#define VENDOR_LENOVO2   0x004F4D
 
 #define PRODUCT_QUANTA_S99Q   21401
 #define PRODUCT_QUANTA_QSSC_S4R  64  /*0x0040*/
