@@ -57,7 +57,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ipmiutil.h"
 
 static char *progname  = "ipmiutil";
-static char *progver   = "3.00";
+static char *progver   = "3.01";
 // static char fdebug = 0;
 /*int ipmiutil(int argc, char **argv); */
 
@@ -83,7 +83,7 @@ static struct {
  { 11, "getevent", i_getevt, "get IPMI events and display them, event daemon" },
  { 12, "health", i_health,  "check and show the basic health of the IPMI BMC"},
  { 13, "hpm",    i_hpm,     "HPM firmware update manager extensions" },
- { 14, "lan",    i_lan,     "show/set IPMI LAN parameters and PEF table"},
+ { 14, "lan",    i_lan,     "show/set IPMI LAN parameters, users, PEF rules"},
  { 15, "picmg",  i_picmg,   "show/set picmg extended functions" },
  { 25, "power",  i_reset,   "issue IPMI reset or power control to the system"},
  { 16, "reset",  i_reset,   "issue IPMI reset or power control to the system"}, 
