@@ -155,7 +155,7 @@ typedef struct
 /*
  * Global variables 
  */
-static char * progver   = "3.00";
+static char * progver   = "3.01";
 static char * progname  = "iserial";
 static int    vend_id = 0;
 static int    prod_id = 0;
@@ -965,10 +965,11 @@ main(int  argc, char **argv)
       if ((ipmi_maj == 0) || (ipmi_maj == 1 && ipmi_min < 5)) {
 	 /* IPMI 0.9 and 1.0 dont support this. */
          printf("This system does not support EMP Terminal Mode.\n");
-	 if (!fdoanyway) 
+         if (!fdoanyway) {
             ret = LAN_ERR_NOTSUPPORT;
             goto do_exit;
          }
+      }
       if (ipmi_maj >= 2) fIPMI20 = 1;
       /* Determine if Basic or Terminal Mode is supported by product id */
       if (vend_id == VENDOR_INTEL) { /*Intel*/
