@@ -403,7 +403,7 @@ int get_errno(void)
  /* For a list of all IANA enterprise mfg vendor numbers, 
   * see http://www.iana.org/assignments/enterprise-numbers 
   * Product numbers are different for each mfg vendor.  */
-#define N_MFG  44
+#define N_MFG  46
 static struct { int val; char *pstr; } mfgs[N_MFG] = {
     {0,   " "},
     {0x0000BA, "Toshiba"},
@@ -448,6 +448,8 @@ static struct { int val; char *pstr; } mfgs[N_MFG] = {
     {VENDOR_LMC,  "LMC"},     /*=0x000878 with SuperMicro*/
     {VENDOR_TYAN, "Tyan"},    /*=0x0019FD*/
     {VENDOR_SUN,  "Sun"},     /*=0x00002A*/
+    {VENDOR_LENOVO, "Lenovo"},  /*=0x004A66*/
+    {VENDOR_LENOVO2, "Lenovo"}, /*=0x004F4D*/
     {VENDOR_INTEL, "Intel"}   /*=0x000157*/
 };
 
